import 'package:healthrian_ble_interface/healthrian_ble_interface.dart';
import 'package:healthrian_common_support/healthrian_common_support.dart';

abstract class ManagerInterface {
  late ModuleInterface module;

  Future<bool> connectDevice([
    String preferredDeviceId = '',
    bool strictConnection = false,
  ]) async {
    return await module.ble.connectDevice(
      preferredDeviceId,
      strictConnection,
    );
  }

  Future<void> disconnectDevice() async {
    await module.ble.disconnectDevice();
  }

  Future<void> registerCharacteristics() async {
    await module.ble.registerCharacteristics();
  }

  Future<void> startMeasurement() async {
    await module.ecg?.start();
    await module.oxi?.start();
  }

  Future<void> stopMeasurement() async {
    await module.ecg?.stop();
    await module.oxi?.stop();
  }

  Future<void> pauseMeasurement() async {
    await module.ecg?.pause();
    await module.oxi?.pause();
  }

  Future<Channels?> saveMeasurement({ModuleType type = ModuleType.ecg}) async {
    if(type == ModuleType.ecg){
      final lastChannel = module.ecg?.lastChannel;
      final dataFilter = module.ecg?.dataFilter;
      if (lastChannel == null) return null;
      return Channels.fromList(lastChannel.list.toList(), dataFilter);
    }

    if(type == ModuleType.oxi){
      final lastChannel = module.oxi?.lastChannel;
      final dataFilter = module.oxi?.dataFilter;
      if (lastChannel == null) return null;
      return Channels.fromList(lastChannel.list.toList(), dataFilter);
    }

    return null;
  }
}
